/*
  metatypebrowserwidget.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "metatypebrowserwidget.h"
#include "ui_metatypebrowserwidget.h"

#include <ui/searchlinecontroller.h>
#include <common/objectbroker.h>

using namespace GammaRay;

MetaTypeBrowserWidget::MetaTypeBrowserWidget(QWidget *parent)
    : QWidget(parent)
    , ui(new Ui::MetaTypeBrowserWidget)
    , m_stateManager(this)
{
    ui->setupUi(this);

    QAbstractItemModel *mtm
        = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.MetaTypeModel"));
    Q_ASSERT(mtm);

    ui->metaTypeView->header()->setObjectName("metaTypeViewHeader");
    ui->metaTypeView->setDeferredResizeMode(0, QHeaderView::ResizeToContents);
    ui->metaTypeView->setDeferredResizeMode(1, QHeaderView::ResizeToContents);
    ui->metaTypeView->setDeferredResizeMode(2, QHeaderView::ResizeToContents);
    ui->metaTypeView->setDeferredResizeMode(3, QHeaderView::ResizeToContents);
    ui->metaTypeView->setModel(mtm);
    ui->metaTypeView->sortByColumn(1, Qt::AscendingOrder); // sort by type id
    new SearchLineController(ui->metaTypeSearchLine, mtm);
}

MetaTypeBrowserWidget::~MetaTypeBrowserWidget()
{
}
